==> regina-normal_4.2.1.orig.tar.gz: regina-4.2.1/python/manifold/pymanifold.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2005, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,        *
 *  MA 02111-1307, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

void addNHandlebody();
void addNManifold();
void addNLensSpace();
void addNSFS();
void addNSimpleSurfaceBundle();
void addNSnapPeaCensusManifold();

void addManifold() {
    addNManifold();
    addNHandlebody();
    addNLensSpace();
    addNSFS();
    addNSimpleSurfaceBundle();
    addNSnapPeaCensusManifold();
}

==> regina-normal_4.3.1.orig.tar.gz: regina-4.3.1/python/manifold/pymanifold.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2006, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

void addNGraphLoop();
void addNGraphPair();
void addNGraphTriple();
void addNHandlebody();
void addNManifold();
void addNLensSpace();
void addNSFSpace();
void addNSimpleSurfaceBundle();
void addNSnapPeaCensusManifold();
void addNTorusBundle();

void addManifold() {
    addNManifold();
    addNHandlebody();
    addNLensSpace();
    addNSFSpace();
    addNSimpleSurfaceBundle();
    addNSnapPeaCensusManifold();
    addNTorusBundle();
    addNGraphLoop();
    addNGraphPair();
    addNGraphTriple();
}
